@@ -31,30 +31,28 @@
 #ifndef RMATH_H
 #define RMATH_H
 
-/* Note that on some systems you need to include math.h before the
-   defines below. If so, define this yourself. */
-#ifndef NO_C_HEADERS
 /* needed for cospi etc */
-# ifndef __STDC_WANT_IEC_60559_FUNCS_EXT__
-#  define __STDC_WANT_IEC_60559_FUNCS_EXT__ 1
-# endif
-/* See the comment in R.h */
+#ifndef __STDC_WANT_IEC_60559_FUNCS_EXT__
+# define __STDC_WANT_IEC_60559_FUNCS_EXT__ 1
+#endif
+#if defined(__cplusplus) && !defined(DO_NOT_USE_CXX_HEADERS)
+# include <cmath>
+// See comment in R.h
 # ifdef __SUNPRO_CC
-#  define DO_NOT_USE_CXX_HEADERS
-# endif
-# if defined(__cplusplus) && !defined(DO_NOT_USE_CXX_HEADERS)
-#  include <cmath>
-# else
-#  include <math.h>
+using namespace std;
 # endif
 #else
-#warning "use of NO_C_HEADERS is deprecated"
+# include <math.h>
+#endif
+
+#ifdef NO_C_HEADERS
+# warning "use of NO_C_HEADERS is defunct and will be ignored"
 #endif
 
 /*-- Mathlib as part of R --  define this for standalone : */
 /* #undef MATHLIB_STANDALONE */
 
-#define R_VERSION_STRING "3.3.2"
+#define R_VERSION_STRING "3.4.2"
 
 #ifndef HAVE_EXPM1
 # define HAVE_EXPM1 1
@@ -625,15 +623,17 @@ double  lgamma1p(double);/* accurate log(gamma(x+1)), small x (0 < x < 0.5) */
 
 /* More accurate cos(pi*x), sin(pi*x), tan(pi*x)
 
-   In future these declarations could clash with system headers if
-   someone had already included math.h with
-   __STDC_WANT_IEC_60559_FUNCS_EXT__ defined.
+   These declarations might clash with system headers if someone had
+   already included math.h with __STDC_WANT_IEC_60559_FUNCS_EXT__
+   defined (and we try, above).
    We can add a check for that via the value of
-   __STDC_IEC_60559_FUNCS__ (>= 201ymmL, exact value not yet known).
+   __STDC_IEC_60559_FUNCS__ (>= 201506L).
 */
+#if !(defined(__STDC_IEC_60559_FUNCS__) && __STDC_IEC_60559_FUNCS__ >= 201506L)
 double cospi(double);
 double sinpi(double);
 double tanpi(double);
+#endif
 
 /* Compute the log of a sum or difference from logs of terms, i.e.,
  *
